@@ -239,9 +239,9 @@ def write_eman1_filament_start_end(filaments, path):
     if not os.path.exists(os.path.dirname(path)):
         os.makedirs(os.path.dirname(path))
 
-    with open(path, "w") as boxfile:
+    with open(path,  "w", newline='', encoding='utf-8') as boxfile:
         boxwriter = csv.writer(
-            boxfile, delimiter="|", quotechar="|", quoting=csv.QUOTE_NONE
+            boxfile, delimiter="\t", quotechar="|", quoting=csv.QUOTE_NONE, lineterminator="\n",
         )
         for fil in filaments:
             fil_boxes = fil.boxes
@@ -380,9 +380,16 @@ def read_eman1_helicon(path, min_distance=0):
 
 def write_eman1_helicon(filaments, path, image_filename):
 
-    with open(path, "w") as boxfile:
+    '''
+    with open(path,  "w", newline='', encoding='utf-8') as boxfile:
         boxwriter = csv.writer(
-            boxfile, delimiter="|", quotechar="|", quoting=csv.QUOTE_NONE
+            boxfile, delimiter="\t", quotechar="|", quoting=csv.QUOTE_NONE, lineterminator="\n",
+        )
+    '''
+
+    with open(path, "w",  newline='', encoding='utf-8') as boxfile:
+        boxwriter = csv.writer(
+            boxfile, delimiter="\t", quotechar="|", quoting=csv.QUOTE_NONE, lineterminator="\n",
         )
         # micrograph: actin_cAla_1_corrfull.mrc
         # segment length: 384
