@@ -90,27 +90,36 @@ def config_configuration_parser(parser_config):
     config_model_group.add_argument(
         "--input_size",
         default=1024,
-        type=int,
-        help="The images are downsized to this size. This is not the size of your micrographs and only rarely needs to be changed.",
+        nargs="+",
+        help="The shorter image dimension is downsized to this size and the long size according the aspect ratio. This is not the size of your micrographs and only rarely needs to be changed. You can also specify height and width of the input image size by seperating them by a whitespace.",
         gooey_options={
             "validator": {
-                "test": "float(user_input)%32 < 1",
-                "message": "Input size has to be multiple of 32!",
+                "test": "float(user_input.split()[0]) % 32 < 1 and float(user_input.split()[1]) % 32 < 1 if len(user_input.split()) == 2 else float(user_input.split()[0]) % 32 < 1",
+                "message": "Input size has to be a multiple of 32!",
             }
         },
     )
+    config_model_group.add_argument(
+        "-nm",
+        "--norm",
+        default="STANDARD",
+        help="Normalization that is applied to the images. Standard will subtract the image mean and devide by the standard deviation."
+             " Experimental: Gaussian Mixture Models (GMM) fit a 2 component GMM to you image data and normalizes according the brighter component. "
+             "This ensures that it always normalize with respect to ice but slows down the training.",
+        choices=["STANDARD", "GMM"],
+    )
 
     config_model_group.add_argument(
         "--num_patches",
         type=int,
         default=1,
-        help='If specified the patch mode will be used. A value of "2" means, that 2×2 patches will be used. A value of "1" means, that no patches will be used (recommended).',
+        help='(DEPRECATED) If specified the patch mode will be used. A value of "2" means, that 2×2 patches will be used. A value of "1" means, that no patches will be used (recommended).',
     )
     config_model_group.add_argument(
         "--overlap_patches",
         type=int,
         default=200,
-        help="Only needed when using patch mode. Specifies how much the patches overlap. In our lab, we always keep the default value.",
+        help="(DEPRECATED) Only needed when using patch mode. Specifies how much the patches overlap. In our lab, we always keep the default value.",
     )
 
     config_denoising_group = parser_config.add_argument_group(
@@ -371,7 +380,11 @@ def main():
                 args.janni_batches,
                 args.filtered_output,
             ]
-
+        if type(args.input_size) == list:
+            if len(args.input_size) == 2:
+                args.input_size = [int(args.input_size[0]),int(args.input_size[1])]
+            elif len(args.input_size) == 1:
+                args.input_size = int(args.input_size[0])
         config_tools.generate_config_file(
             config_out_path=args.config_out_path,
             architecture=args.architecture,
@@ -398,6 +411,7 @@ def main():
             valid_image_folder=args.valid_image_folder,
             valid_annot_folder=args.valid_annot_folder,
             valid_times=1,
+            normalization=args.norm
         )
     elif "train" in sys.argv[1]:
         import cryolo.train as train
